#
# spec file for package python-opentelemetry-exporter-otlp-proto-http
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-opentelemetry-exporter-otlp-proto-http
Version:        1.27.0
Release:        1.1
Summary:        OpenTelemetry Collector Protobuf over HTTP Exporter
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-exporter-otlp-proto-http/opentelemetry_exporter_otlp_proto_http-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Deprecated >= 1.2.6}
BuildRequires:  %{python_module googleapis-common-protos >= 1.52}
BuildRequires:  %{python_module opentelemetry-api >= 1.15}
BuildRequires:  %{python_module opentelemetry-exporter-otlp-proto-common = %{version}}
BuildRequires:  %{python_module opentelemetry-proto = %{version}}
BuildRequires:  %{python_module opentelemetry-sdk >= 1.23.0}
BuildRequires:  %{python_module opentelemetry-test-utils}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.7}
BuildRequires:  %{python_module responses >= 0.22.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-Deprecated >= 1.2.6
Requires:       python-googleapis-common-protos >= 1.52
Requires:       python-opentelemetry-api >= 1.15
Requires:       python-opentelemetry-exporter-otlp-proto-common = %{version}
Requires:       python-opentelemetry-proto = %{version}
Requires:       python-opentelemetry-sdk >= 1.23.0
Requires:       python-requests >= 2.7
BuildArch:      noarch
%python_subpackages

%description
This library allows to export data to the OpenTelemetry Collector using the
OpenTelemetry Protocol using Protobuf over HTTP.

%prep
%autosetup -p1 -n opentelemetry_exporter_otlp_proto_http-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%dir %{python_sitelib}/opentelemetry
%dir %{python_sitelib}/opentelemetry/exporter
%dir %{python_sitelib}/opentelemetry/exporter/otlp/
%dir %{python_sitelib}/opentelemetry/exporter/otlp/proto
%{python_sitelib}/opentelemetry/exporter/otlp/proto/http
%{python_sitelib}/opentelemetry_exporter_otlp_proto_http-%{version}.dist-info

%changelog
* Wed Sep 11 2024 Dirk Müller <dmueller@suse.com>
- update to 1.27.0:
  * Implementation of Events API
  * Make log sdk add `exception.message` to logRecord for
    exceptions whose argument is an exception not a string
    message
  * Fix use of `link.attributes.dropped`, which may not exist
  * Running mypy on SDK resources
  * Added py.typed file to top-level module
  * Drop Final annotation from Enum in semantic conventions
  * Update log export example to not use root logger
  * sdk: Add OS resource detector
  * sdk: Accept non URL-encoded headers in
    `OTEL_EXPORTER_OTLP_*HEADERS` to match other languages SDKs
  * Update semantic conventions to version 1.27.0
  * Add support to type bytes for OTLP AnyValue
  * Export ExponentialHistogram and ExponentialHistogramDataPoint
  * Implement Client Key and Certificate File Support for All
    OTLP Exporters
  * Remove `_start_time_unix_nano` attribute from
    `_ViewInstrumentMatch` in favor of using `time_ns()` at the
    moment when the aggregation object is created
- update to 1.26.0:
  * Standardizing timeout calculation in measurement consumer
    collect to nanoseconds
  * optional scope attributes for logger creation
  * optional scope attribute for tracer creation
  * OTLP exporter is encoding invalid span/trace IDs in the logs
    fix
  * Update sdk process resource detector `process.command_args`
    attribute to also include the executable itself
  * Fix `start_time_unix_nano` for delta collection for explicit
    bucket histogram aggregation
  * Fix `start_time_unix_nano` for delta collection for sum
    aggregation
  * Update opentracing and opencesus docs examples to not use
    JaegerExporter
  * Do not execute Flask Tests in debug mode
  * When encountering an error encoding metric attributes in the
    OTLP exporter, log the key that had an error.
  * Fix `ExponentialHistogramAggregation`
  * Log a warning when a `LogRecord` in `sdk/log` has dropped
    attributes due to reaching limits
  * Fix RandomIdGenerator can generate invalid Span/Trace Ids
  * Add Python 3.12 to tox
  * Improve resource field structure for LogRecords
  * Update Semantic Conventions code generation scripts:  - fix
    namespace exclusion that resulted in dropping  `os` and `net`
    namespaces.  - add `Final` decorator to constants to prevent
    collisions  - enable mypy and fix detected issues  - allow to
    drop specific attributes in preparation for Semantic
    Conventions v1.26.0
  * Update semantic conventions to version 1.26.0.
  * Use semconv exception attributes for record exceptions in
    spans
  * Fix _encode_events assumes events.attributes.dropped exists
  * Validate links at span creation
  * Add attributes field in  `MeterProvider.get_meter` and
    `InstrumentationScope`
  * Fix inaccessible `SCHEMA_URL` constants in `opentelemetry-
    semantic-conventions`
* Mon Jun 17 2024 Dirk Müller <dmueller@suse.com>
- update to 1.25.0:
  * Fix class BoundedAttributes to have RLock rather than Lock
  * Remove thread lock by loading RuntimeContext explicitly.
  * Update proto version to v1.2.0
  * Add to_json method to ExponentialHistogram
  * Bump mypy to 1.9.0
  * Fix exponential histograms
  * Fix otlp exporter to export log_record.observed_timestamp
  * Add capture the fully qualified type name for raised
    exceptions in spans
  * Prometheus exporter sort label keys to prevent duplicate
    metrics when user input changes order
  * Rename test objects to avoid pytest warnings
  * Add span flags to OTLP spans and links
  * Record links with invalid SpanContext if either attributes or
    TraceState are not empty
  * Add OpenTelemetry trove classifiers to PyPI packages ([#3913]
  * Fix prometheus metric name and unit conversion (#3924)
  * Add parameters for Distros and configurators to configure
    autoinstrumentation in addition to existing environment
    variables.
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Make create_gauge non-abstract method
  * Make `tracer.start_as_current_span()` decorator work with
    async functions
  * Fix python 3.12 deprecation warning
  * bump mypy to 0.982
  * Add support for OTEL_SDK_DISABLED environment variable
  * Fix ValueError message for PeriodicExportingMetricsReader
  * Use `BaseException` instead of `Exception` in
    `record_exception`
  * Make span.record_exception more robust
  * Fix license field in pyproject.toml files
* Sat Mar 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- update to 1.23.0:
  * Use Attribute rather than boundattribute in logrecord (#3567)
  * Fix flush error when no LoggerProvider configured for LoggingHandler (#3608)
  * Fix OTLPMetricExporter ignores preferred_aggregation property (#3603)
  * Logs: set observed_timestamp field (#3565)
  * Add missing Resource SchemaURL in OTLP exporters (#3652)
  * Fix loglevel warning text (#3566)
  * Prometheus Exporter string representation for target_info labels (#3659)
  * Logs: ObservedTimestamp field is missing in console exporter output (#3564)
  * Fix explicit bucket histogram aggregation (#3429)
  * Add code.lineno, code.function and code.filepath to all logs (#3645)
  * Add Synchronous Gauge instrument (#3462)
  * Drop support for 3.7 (#3668)
  * Include key in attribute sequence warning (#3639)
  * Upgrade markupsafe, Flask and related dependencies to dev and test
    environments (#3609)
  * Handle HTTP 2XX responses as successful in OTLP exporters (#3623)
  * Improve Resource Detector timeout messaging (#3645)
  * Add Proxy classes for logging (#3575)
  * Remove dependency on 'backoff' library (#3679)
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- Initial package (1.22.0)
